==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/template/barnraiser_01/mag_overview.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="mag_overview.php" method="post">

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="370" valign="top">
			<div class="box_top">
				<?php echo $lang['section_blogs'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				if (!empty($i['rsp_sticky'])) {
				unset($blogs[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="0" cellspacing="0" border="0">
			   				<tr>
			   					<td valign="top">
			   						<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
			   					</td>
								<td>
			   						<img src="<?php echo $templatePath;?>img/pixel.png" width="9" height="1" alt="" /><br />
								</td>
			   					<td valign="top">
			   						<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_title'];?></a><br />
			   						<p>
			   						<?php echo $i['blog_create_datetime'];?>
			   						&nbsp;&#47;&nbsp;
			   						<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
			   						<?php echo $i['blog_synopsis'];?><br />
			   						</p>
			   					</td>
			   				</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['blog_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<div class="box_top">
				<?php echo $lang['section_subjects'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				if (!empty($i['rsp_sticky'])) {
				unset($subjects[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="0" cellspacing="0" border="0">
							<tr>
								<td width="80" valign="top">
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td>
			   						<img src="<?php echo $templatePath;?>img/pixel.png" width="9" height="1" alt="" /><br />
								</td>
								<td valign="top">
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_title'];?></a><br />
									<p>
									<?php echo $i['subject_create_datetime'];?>
									&nbsp;&#47;&nbsp;
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
									<?php echo $i['subject_body'];?><br />
									</p>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['subject_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>

		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">
 			<div class="box_top">
				<?php echo $lang['section_polls'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<?php
				if (isset($polls)) {
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
						$poll_url = "mag_item.php?poll_id=" . $i['poll_id'];
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
				}
 				?>
 			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
 			<div class="box_top">
				<?php echo $lang['section_library_items'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($library_items)) {
				foreach($library_items as $key => $i):
				if (!empty($i['rsp_sticky'])) {
				unset($library_items[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="0" cellspacing="0" border="0">
							<tr>
								<td width="80" valign="top">
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td>
			   						<img src="<?php echo $templatePath;?>img/pixel.png" width="9" height="1" alt="" /><br />
								</td>
								<td valign="top">
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_title'];?></a><br />
									<p>
									<?php echo $i['library_create_datetime'];?>
									&nbsp;&#47;&nbsp;
									<?php echo $lang['txt_genre'];?>: <?php if (isset($i['genre_id']) && $i['genre_id'] > 0) { echo $lang['arr_genre'][$i['genre_id']];}?><br />
									<?php echo $i['library_synopsis'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($library_items)) {
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['library_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/template/barnraiser_01/mag_overview.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="mag_overview.php" method="post">

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="370" valign="top">
			<div class="box_top">
				<?php echo $lang['section_blogs'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				if (!empty($i['rsp_sticky'])) {
				unset($blogs[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="0" cellspacing="0" border="0">
			   				<tr>
			   					<td valign="top">
			   						<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
			   					</td>
								<td>
			   						<img src="<?php echo $templatePath;?>img/pixel.png" width="9" height="1" alt="" /><br />
								</td>
			   					<td valign="top">
			   						<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
			   						<p>
			   						<b><?php echo $i['blog_title'];?></b><br />
			   						<?php echo $i['blog_synopsis'];?><br />
			   						</p>
			   					</td>
			   				</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($blogs)) {
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $i['blog_title'];?></b><br />
									<?php echo $i['blog_synopsis'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
			<div class="box_top">
				<?php echo $lang['section_subjects'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				if (!empty($i['rsp_sticky'])) {
				unset($subjects[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="0" cellspacing="0" border="0">
							<tr>
								<td width="80" valign="top">
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td>
			   						<img src="<?php echo $templatePath;?>img/pixel.png" width="9" height="1" alt="" /><br />
								</td>
								<td valign="top">
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
									<p>
									<b><?php echo $i['subject_title'];?></b><br />
									<?php echo dots(220, $i['subject_body']);?><br />
									</p>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($subjects)) {
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<b><?php echo $i['subject_title'];?></b><br />
									<?php echo dots(220, $i['subject_body']);?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>

		</td>

		<td width="20">&nbsp;</td>

		<td width="370" valign="top">
 			<div class="box_top">
				<?php echo $lang['section_polls'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<?php
				if (isset($polls)) {
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
						$poll_url = "mag_item.php?poll_id=" . $i['poll_id'];
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
				}
 				?>
 			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			
 			<div class="box_top">
				<?php echo $lang['section_library_items'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<?php
				if (isset($library_items)) {
				foreach($library_items as $key => $i):
				if (!empty($i['rsp_sticky'])) {
				unset($library_items[$key]);
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="0" cellspacing="0" border="0">
							<tr>
								<td width="80" valign="top">
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><img align="left" src="get_file.php?file=<?php echo $i['image']['file'];?>" border="0" class="picture" title="<?php echo $i['image']['file_title'];?>"></a>
								</td>
								<td>
			   						<img src="<?php echo $templatePath;?>img/pixel.png" width="9" height="1" alt="" /><br />
								</td>
								<td valign="top">
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
									<p>
									<b><?php echo $i['library_title'];?></b><br />
									<?php echo dots(220, $i['library_synopsis']);?><br />
									</p>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				}
				endforeach;
				}
				?>
				<?php
				if (isset($library_items)) {
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0" class="table_nested">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="mag_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<p>
									<b><?php echo $i['library_title'];?></b><br />
									<?php echo dots(220, $i['library_synopsis']);?><br />
									</p>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				}
				?>
			</table>
			</div>
			
			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
</form>
